/*
 * Copyright 2016 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.record8;

import java.io.IOException;

import dk.vajhoej.record.LengthProvider;
import dk.vajhoej.record.LengthProvider2;
import dk.vajhoej.record.RecordException;
import dk.vajhoej.record.Util2;

class Lambda2Interface {
	static LengthProvider convert(final LengthFunction lenfunc) {
		return new LengthProvider() {
			@Override
			public int getLength(Object o, int n) {
				return lenfunc.getLength(o, n);
			}
		};
	}
	static LengthProvider2 convert(final LengthFunction lenfunc, final MaxLengthFunction maxlenfunc) {
		return new LengthProvider2() {
			@Override
			public int getLength(Object o, int n) {
				return lenfunc.getLength(o, n);
			}
			@Override
			public int getMaxLength() {
				return maxlenfunc.getMaxLength();
			}
			@Override
			public int getElements(Object o, int n) {
				return -1;
			}
			@Override
			public LengthProvider2 getLengthProvider(Object o, int n) {
				return null;
			}
		};
	}
	static LengthProvider2 convert(final LengthFunction lenfunc, final MaxLengthFunction maxlenfunc, final ElementsFunction elmfunc) {
		return new LengthProvider2() {
			@Override
			public int getLength(Object o, int n) {
				return lenfunc.getLength(o, n);
			}
			@Override
			public int getMaxLength() {
				return maxlenfunc.getMaxLength();
			}
			@Override
			public int getElements(Object o, int n) {
				return elmfunc.getElements(o, n);
			}
			@Override
			public LengthProvider2 getLengthProvider(Object o, int n) {
				return null;
			}
		};
	}
	static <T> Util2.ObjectHandler<T> convert(final HandlerFunction<T> hfunc) {
		return new Util2.ObjectHandler<T>() {
			@Override
			public void process(T o) throws RecordException, IOException {
				hfunc.process(o);
			}
		};
	}
	static <T1,T2> Util2.Transformer<T1,T2> convert(final TransformerFunction<T1,T2> tfunc) {
		return new Util2.Transformer<T1,T2>() {
			@Override
			public T2 convert(T1 o) {
				return tfunc.convert(o);
			}
		};
	}
}
